package org.acme.redis;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class IncrementResourceInGraalIT extends IncrementResourceTest {

}
